@@ -1,10 +1,17 @@
-use std::{collections::HashMap, sync::Mutex};
+use {
+    fnv::FnvHashMap,
+    once_cell::sync::Lazy,
+    std::sync::Mutex,
+};
+
+pub fn supported() -> bool {
+    true
+}
 
-#[cfg(unix)]
 pub fn user_name(uid: u32) -> String {
-    lazy_static! {
-        static ref USERS_CACHE_MUTEX: Mutex<HashMap<u32, String>> = Mutex::new(HashMap::new());
-    }
+    static USERS_CACHE_MUTEX: Lazy<Mutex<FnvHashMap<u32, String>>> = Lazy::new(|| {
+            Mutex::new(FnvHashMap::default())
+    });
     let mut users_cache = USERS_CACHE_MUTEX.lock().unwrap();
     let name = users_cache
         .entry(uid)
@@ -17,12 +24,11 @@ pub fn user_name(uid: u32) -> String {
     (*name).to_string()
 }
 
-#[cfg(unix)]
 pub fn group_name(gid: u32) -> String {
-    lazy_static! {
-        static ref USERS_CACHE_MUTEX: Mutex<HashMap<u32, String>> = Mutex::new(HashMap::new());
-    }
-    let mut groups_cache = USERS_CACHE_MUTEX.lock().unwrap();
+    static GROUPS_CACHE_MUTEX: Lazy<Mutex<FnvHashMap<u32, String>>> = Lazy::new(|| {
+        Mutex::new(FnvHashMap::default())
+    });
+    let mut groups_cache = GROUPS_CACHE_MUTEX.lock().unwrap();
     let name = groups_cache
         .entry(gid)
         .or_insert_with(|| {
